/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.security;

/**
 * The Access List Key Manager allow to hide the manipulation key for the
 * developer and generate it. A manipulation key is a string associated to a
 * manipulation that a user can be allowed to or not.
 * 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
 */
public class ACLKeyManager {

  public static final String ORCHESTRA_GROUP = "orchestra";
  public static final String ALL = "*";

  private static String actionString = "action";
  private static String viewString = "view";

  /* Key generation */
  /**
   * Generate a security key for an action
   * 
   * @param group group or profil
   * @param entity an entity
   * @param action an action
   * @return the action key for the specified group and entity
   * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   */
  public String generateActionKey(String group, String entity, String action) {
    return group + "." + actionString + "." + entity + "." + action;
  }
  /**
   * Generate a security key for a view
   * 
   * @param group group or profil
   * @param entity an entity
   * @return the view key for the specified group, and entity
   * @author Le Gall Rodrigue <rodrigue.le-gall@bull.net>
   * @author Elwalid Brahim <elwalid.brahim@bull.net>
   * @todo check if this method is usefull
   */
  public String generateViewKey(String group, String entity) {
    return group + "." + viewString + "." + entity;
  }
}
