/**
 * Copyright (C) 2008  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.console.security;

import org.picocontainer.Startable;

/**
 * The Security service allow to manage all the security entities. It's the
 * entry point for all the items that need to access to the security part.
 * 
 * @author Elwalid Brahim <elwalid.brahim@bull.net>
 */

public class SecurityService implements Startable {

  /**
   * The key manager
   */
  private ACLKeyManager aclKeyManager;

  /**
   * The profile manager
   */
  private ProfileManager profileManager;

  /**
   * The access list
   */
  private NovaACL acl;

  /**
   * The start method of the security service set the default configuration and
   * prepare all the security tools
   */
  public void start() {
    this.aclKeyManager = new ACLKeyManager();
    this.profileManager = new ProfileManager();
    this.acl = new NovaACL(this.profileManager);
    SecurityConfiguration securityConf = new SecurityConfiguration();
    securityConf.setDefaultConfiguration();
  }

  /**
   * Get the key manager
   * 
   * @return key manager
   */
  public ACLKeyManager getACLKeyManager() {
    return this.aclKeyManager;
  }

  /**
   * Get the user access list
   * 
   * @return nova access list
   */
  public NovaACL getUserACL() {
    return this.acl;
  }

  /**
   * Get the profile manager
   * 
   * @return profile manager
   */
  public ProfileManager getProfileManager() {
    return this.profileManager;
  }

  /**
   * The stop method
   */
  public void stop() {
  }

}
